# OneNeuron_pypi
OneNeuron_pypi


# Refernces
[Python official docs](https://packaging.python.org/en/latest/tutorials/packaging-projects/)


[Github docs for github actions](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)




